@@ -1,18 +1,16 @@
       dcc.estimation <- function(inia, iniA, iniB, ini.dcc, dvar, model){
+         dvar <- as.matrix(dvar)
          ndim <- dim(dvar)[2]
          In <- diag(ndim)
-            cat("***********************************************************\n")
-            cat("*  Doing the first stage estimation..............         *\n")
-            cat("*                                                         *\n")
+         
+         if(!is.matrix(iniA)||!is.matrix(iniB)){
+            stop("iniA or iniB or both must be matrices")
+         }
+         
          first.stage <- dcc.estimation1(dvar=dvar, a=inia, A=iniA, B=iniB, model=model)
-         if(first.stage$convergence == 0){
-            cat("*  The first stage completed!                             *\n")
-            cat("*                                                         *\n")
-            cat("*  Proceed to the second stage estimation.                *\n")
-            cat("*                                                         *\n")
-            cat("*  Please wait for a while.......................         *\n")
-         } else {
-            cat("* Optimization is FAILED.                                 *\n")
+         if(first.stage$convergence != 0){
+            cat("***********************************************************\n")
+            cat("* The first stage optimization is failed.                 *\n")
             cat("* Fine tuning is required. Unfortunately, this has to be  *\n")
             cat("* done manually. However, some functions like             *\n")
             cat("* loglik.dcc1 can be used. See the manual for details.    *\n")
@@ -31,11 +29,12 @@
          second.stage <- dcc.estimation2(std.resid, ini.dcc, gradient=1)
          
          if(second.stage$convergence != 0){
-            cat("* Optimization is failed.                                  \n")
+            cat("***********************************************************\n")
+            cat("* The second stage ptimization is failed.                  \n")
             cat("***********************************************************\n")
          } else {
-            cat("*                                                         *\n")
-            cat("*  All the estimation has been completed.                 *\n")
+            cat("***********************************************************\n")
+            cat("*  Estimation has been completed.                         *\n")
             cat("*  The outputs are saved in a list with components:       *\n")
             cat("*    out    : the estimates and their standard errors     *\n")
             cat("*    h      : a matrix of volatility estimates            *\n")
